@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import os
 
 
@@ -16,6 +15,8 @@ USE_TZ = True
 
 USE_THOUSAND_SEPARATOR = True
 
+DB_URL = os.environ.get("DATABASE_URL", "postgresql://postgres:postgres@localhost") + "/test"
+
 SECRET_KEY = "secret"
 
 ALLOWED_HOSTS = ["*"]
